package com.ynet.life.loaf;

import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf.jar:com/ynet/life/loaf/TableConfig.class */
public class TableConfig {
    private static final String BUSINESS_SEPERATOR = ",";
    private static final String JOIN_SEPERATOR = "||";
    private String businessCode;
    private String tableName;
    private Map dataToTableMap = new HashMap();
    private Map tableToDataMap = new HashMap();
    private Set primaryKeySet = new HashSet();
    private Map contextFieldMap = new HashMap();
    private Set joinedKeySet = new HashSet();
    private Set searchKeySet = new HashSet();
    private List subBusinessList = new ArrayList();
    private List showBusinessList = new ArrayList();

    public TableConfig(String businessCode, String tableName, String subBusinessCode, String showBusinessCode) {
        this.businessCode = businessCode;
        this.tableName = tableName;
        setSubBusinessCode(subBusinessCode);
        setShowBusinessCode(showBusinessCode);
    }

    public static Map initFormFile(String filePathName) throws TranFailException {
        new HashMap();
        return new TableConfigXMLReader(filePathName).getConfigs();
    }

    public void addDataTableField(String dataField, String tableField, String isPrimaryKey, String isJoinedKey, String contextFiled, String isSearchKey) throws TranFailException {
        if (this.dataToTableMap.containsKey(dataField) || this.tableToDataMap.containsKey(tableField)) {
            Trace.logError("LOAF", "数据字段名[" + dataField + "]或者表字段名[" + tableField + "]重复定义");
            throw new TranFailException("EBLN0000", "数据字段名[" + dataField + "]或者表字段名[" + tableField + "]重复定义");
        }
        this.dataToTableMap.put(dataField, tableField);
        this.tableToDataMap.put(tableField, dataField);
        this.contextFieldMap.put(dataField, contextFiled);
        if (Boolean.valueOf(isPrimaryKey).booleanValue()) {
            this.primaryKeySet.add(tableField);
        }
        if (Boolean.valueOf(isJoinedKey).booleanValue()) {
            this.joinedKeySet.add(tableField);
        }
        if (Boolean.valueOf(isSearchKey).booleanValue()) {
            this.searchKeySet.add(dataField);
        }
    }

    public List getSubBusinessList() {
        return this.subBusinessList;
    }

    public List getShowBusinessList() {
        return this.showBusinessList;
    }

    private final void setSubBusinessCode(String subBsnCode) {
        this.subBusinessList.clear();
        if (subBsnCode != null) {
            StringTokenizer toker = new StringTokenizer(subBsnCode, BUSINESS_SEPERATOR);
            while (toker.hasMoreElements()) {
                this.subBusinessList.add(toker.nextElement());
            }
        }
    }

    private final void setShowBusinessCode(String showBsnCode) {
        this.showBusinessList.clear();
        if (showBsnCode != null) {
            StringTokenizer token = new StringTokenizer(showBsnCode, BUSINESS_SEPERATOR);
            while (token.hasMoreElements()) {
                this.showBusinessList.add(token.nextElement());
            }
        }
    }

    public String getTableName() {
        return this.tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public Map getTableFieldToDataHashMap() {
        return this.tableToDataMap;
    }

    public Map getDataToTableFieldHashMap() {
        return this.dataToTableMap;
    }

    public Set getPrimaryKeyHashMap() {
        return this.primaryKeySet;
    }

    public Map getContextFieldMap() {
        return this.contextFieldMap;
    }

    public String getBusinessCode() {
        int seperatorPos = this.businessCode.indexOf(BUSINESS_SEPERATOR);
        if (seperatorPos > 0) {
            return this.businessCode.substring(0, seperatorPos);
        }
        return this.businessCode;
    }

    public boolean isJoinedPK(String tableFieldName) {
        return this.primaryKeySet.contains(tableFieldName) && this.joinedKeySet.contains(tableFieldName);
    }

    public String getJoinedValue(String tableFieldName, Map map) {
        StringBuffer result = new StringBuffer();
        List fieldList = getJoinedPKList(tableFieldName);
        int size = fieldList.size();
        for (int i = 0; i < size; i++) {
            String contextFieldName = (String) fieldList.get(i);
            result.append((String) map.get(contextFieldName));
        }
        return result.toString();
    }

    public List getJoinedPKList(String tableFieldName) {
        List result = new ArrayList();
        String joinedField = (String) this.tableToDataMap.get(tableFieldName);
        StringTokenizer token = new StringTokenizer(joinedField, JOIN_SEPERATOR);
        while (token.hasMoreElements()) {
            result.add(token.nextElement());
        }
        return result;
    }

    public Set getJoinedPKHashSet() {
        Set result = new HashSet();
        for (String pk : this.primaryKeySet) {
            if (isJoinedPK(pk)) {
                result.addAll(getJoinedPKList(pk));
            }
        }
        return result;
    }

    public String getFields() {
        StringBuffer fieldList = new StringBuffer();
        Iterator iterator = getTableFieldToDataHashMap().keySet().iterator();
        while (iterator.hasNext()) {
            String tableField = (String) iterator.next();
            if (iterator.hasNext()) {
                fieldList.append(tableField).append(BUSINESS_SEPERATOR);
            } else {
                fieldList.append(tableField);
            }
        }
        return fieldList.toString();
    }

    public Set getSearchKeySet() {
        return this.searchKeySet;
    }
}
